# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/atlas/testing_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.atlas import testing_checker_pb2 as eolymp_dot_atlas_dot_testing__checker__pb2
from eolymp.atlas import testing_config_pb2 as eolymp_dot_atlas_dot_testing__config__pb2
from eolymp.atlas import testing_interactor_pb2 as eolymp_dot_atlas_dot_testing__interactor__pb2
from eolymp.atlas import testing_test_pb2 as eolymp_dot_atlas_dot_testing__test__pb2
from eolymp.atlas import testing_testset_pb2 as eolymp_dot_atlas_dot_testing__testset__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"eolymp/atlas/testing_service.proto\x12\x0c\x65olymp.atlas\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\"eolymp/atlas/testing_checker.proto\x1a!eolymp/atlas/testing_config.proto\x1a%eolymp/atlas/testing_interactor.proto\x1a\x1f\x65olymp/atlas/testing_test.proto\x1a\"eolymp/atlas/testing_testset.proto\"G\n\x18UpdateTestingConfigInput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"\x1b\n\x19UpdateTestingConfigOutput\"-\n\x1a\x44\x65scribeTestingConfigInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"J\n\x1b\x44\x65scribeTestingConfigOutput\x12+\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x1b.eolymp.atlas.TestingConfig\"<\n\x12UpdateCheckerInput\x12&\n\x07\x63hecker\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"\x15\n\x13UpdateCheckerOutput\"\'\n\x14\x44\x65scribeCheckerInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeCheckerOutput\x12&\n\x07\x63hecker\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Checker\"E\n\x15UpdateInteractorInput\x12,\n\ninteractor\x18\x02 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"\x18\n\x16UpdateInteractorOutput\"*\n\x17\x44\x65scribeInteractorInput\x12\x0f\n\x07version\x18\x64 \x01(\r\"H\n\x18\x44\x65scribeInteractorOutput\x12,\n\ninteractor\x18\x01 \x01(\x0b\x32\x18.eolymp.atlas.Interactor\"B\n\x11ListTestsetsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x0f\n\x07version\x18\x64 \x01(\r\"I\n\x12ListTestsetsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12$\n\x05items\x18\x02 \x03(\x0b\x32\x15.eolymp.atlas.Testset\";\n\x14\x44\x65scribeTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"?\n\x15\x44\x65scribeTestsetOutput\x12&\n\x07testset\x18\x01 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"<\n\x12\x43reateTestsetInput\x12&\n\x07testset\x18\x02 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"!\n\x13\x43reateTestsetOutput\x12\n\n\x02id\x18\x01 \x01(\t\"P\n\x12UpdateTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12&\n\x07testset\x18\x03 \x01(\x0b\x32\x15.eolymp.atlas.Testset\"\x15\n\x13UpdateTestsetOutput\"(\n\x12\x44\x65leteTestsetInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteTestsetOutput\"$\n\x11ListExamplesInput\x12\x0f\n\x07version\x18\x64 \x01(\r\":\n\x12ListExamplesOutput\x12$\n\x08\x65xamples\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"5\n\x0eListTestsInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"C\n\x0fListTestsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12!\n\x05items\x18\x02 \x03(\x0b\x32\x12.eolymp.atlas.Test\"I\n\x11\x44\x65scribeTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x64 \x01(\r\"6\n\x12\x44\x65scribeTestOutput\x12 \n\x04test\x18\x01 \x01(\x0b\x32\x12.eolymp.atlas.Test\"G\n\x0f\x43reateTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12 \n\x04test\x18\x03 \x01(\x0b\x32\x12.eolymp.atlas.Test\"#\n\x10\x43reateTestOutput\x12\x0f\n\x07test_id\x18\x01 \x01(\t\"\x9a\x02\n\x0fUpdateTestInput\x12\x32\n\x05patch\x18\x05 \x03(\x0e\x32#.eolymp.atlas.UpdateTestInput.Patch\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\x12 \n\x04test\x18\x04 \x01(\x0b\x32\x12.eolymp.atlas.Test\"\x8b\x01\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\x0b\n\x07\x45XAMPLE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\t\n\x05SCORE\x10\x03\x12\t\n\x05INPUT\x10\x04\x12\n\n\x06\x41NSWER\x10\x05\x12\t\n\x05INDEX\x10\x08\x12\n\n\x06SECRET\x10\t\x12\x11\n\rEXAMPLE_INPUT\x10\x06\x12\x12\n\x0e\x45XAMPLE_ANSWER\x10\x07\"\x12\n\x10UpdateTestOutput\"6\n\x0f\x44\x65leteTestInput\x12\x12\n\ntestset_id\x18\x02 \x01(\t\x12\x0f\n\x07test_id\x18\x03 \x01(\t\"\x12\n\x10\x44\x65leteTestOutput2\xa8\x15\n\x0eTestingService\x12\xa2\x01\n\x13UpdateTestingConfig\x12&.eolymp.atlas.UpdateTestingConfigInput\x1a\'.eolymp.atlas.UpdateTestingConfigOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/testing\x12\xa8\x01\n\x15\x44\x65scribeTestingConfig\x12(.eolymp.atlas.DescribeTestingConfigInput\x1a).eolymp.atlas.DescribeTestingConfigOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\n\x12\x08/testing\x12\x90\x01\n\rUpdateChecker\x12 .eolymp.atlas.UpdateCheckerInput\x1a!.eolymp.atlas.UpdateCheckerOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\x1a\x08/checker\x12\x96\x01\n\x0f\x44\x65scribeChecker\x12\".eolymp.atlas.DescribeCheckerInput\x1a#.eolymp.atlas.DescribeCheckerOutput\":\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\n\x12\x08/checker\x12\x9c\x01\n\x10UpdateInteractor\x12#.eolymp.atlas.UpdateInteractorInput\x1a$.eolymp.atlas.UpdateInteractorOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\r\x1a\x0b/interactor\x12\xa2\x01\n\x12\x44\x65scribeInteractor\x12%.eolymp.atlas.DescribeInteractorInput\x1a&.eolymp.atlas.DescribeInteractorOutput\"=\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\r\x12\x0b/interactor\x12\x91\x01\n\rCreateTestset\x12 .eolymp.atlas.CreateTestsetInput\x1a!.eolymp.atlas.CreateTestsetOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0b\"\t/testsets\x12\x9e\x01\n\rUpdateTestset\x12 .eolymp.atlas.UpdateTestsetInput\x1a!.eolymp.atlas.UpdateTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x1a\x16/testsets/{testset_id}\x12\x9e\x01\n\rDeleteTestset\x12 .eolymp.atlas.DeleteTestsetInput\x1a!.eolymp.atlas.DeleteTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18*\x16/testsets/{testset_id}\x12\xa4\x01\n\x0f\x44\x65scribeTestset\x12\".eolymp.atlas.DescribeTestsetInput\x1a#.eolymp.atlas.DescribeTestsetOutput\"H\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x18\x12\x16/testsets/{testset_id}\x12\x8e\x01\n\x0cListTestsets\x12\x1f.eolymp.atlas.ListTestsetsInput\x1a .eolymp.atlas.ListTestsetsOutput\";\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x0b\x12\t/testsets\x12\x9c\x01\n\nCreateTest\x12\x1d.eolymp.atlas.CreateTestInput\x1a\x1e.eolymp.atlas.CreateTestOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02\x1e\"\x1c/testsets/{testset_id}/tests\x12\xa6\x01\n\nUpdateTest\x12\x1d.eolymp.atlas.UpdateTestInput\x1a\x1e.eolymp.atlas.UpdateTestOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02(\x1a&/testsets/{testset_id}/tests/{test_id}\x12\xa6\x01\n\nDeleteTest\x12\x1d.eolymp.atlas.DeleteTestInput\x1a\x1e.eolymp.atlas.DeleteTestOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0c\xf5\xe2\n\x00\x00 A\xf8\xe2\n\xc8\x01\x82\xd3\xe4\x93\x02(*&/testsets/{testset_id}/tests/{test_id}\x12\xab\x01\n\x0c\x44\x65scribeTest\x12\x1f.eolymp.atlas.DescribeTestInput\x1a .eolymp.atlas.DescribeTestOutput\"X\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02(\x12&/testsets/{testset_id}/tests/{test_id}\x12\x98\x01\n\tListTests\x12\x1c.eolymp.atlas.ListTestsInput\x1a\x1d.eolymp.atlas.ListTestsOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13\x61tlas:problem:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1e\x12\x1c/testsets/{testset_id}/tests\x12\x8d\x01\n\x0cListExamples\x12\x1f.eolymp.atlas.ListExamplesInput\x1a .eolymp.atlas.ListExamplesOutput\":\x82\xe3\n\x16\x8a\xe3\n\x12\x61tlas:problem:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0\x41\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x0b\x12\t/examplesB-Z+github.com/eolymp/go-sdk/eolymp/atlas;atlasb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.atlas.testing_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/atlas;atlas'
  _TESTINGSERVICE.methods_by_name['UpdateTestingConfig']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\n\032\010/testing'
  _TESTINGSERVICE.methods_by_name['DescribeTestingConfig']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTestingConfig']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\n\022\010/testing'
  _TESTINGSERVICE.methods_by_name['UpdateChecker']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateChecker']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\n\032\010/checker'
  _TESTINGSERVICE.methods_by_name['DescribeChecker']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeChecker']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\n\022\010/checker'
  _TESTINGSERVICE.methods_by_name['UpdateInteractor']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\r\032\013/interactor'
  _TESTINGSERVICE.methods_by_name['DescribeInteractor']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeInteractor']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\r\022\013/interactor'
  _TESTINGSERVICE.methods_by_name['CreateTestset']._options = None
  _TESTINGSERVICE.methods_by_name['CreateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\013\"\t/testsets'
  _TESTINGSERVICE.methods_by_name['UpdateTestset']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030\032\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['DeleteTestset']._options = None
  _TESTINGSERVICE.methods_by_name['DeleteTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000\240@\370\342\n2\202\323\344\223\002\030*\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['DescribeTestset']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTestset']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\030\022\026/testsets/{testset_id}'
  _TESTINGSERVICE.methods_by_name['ListTestsets']._options = None
  _TESTINGSERVICE.methods_by_name['ListTestsets']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\013\022\t/testsets'
  _TESTINGSERVICE.methods_by_name['CreateTest']._options = None
  _TESTINGSERVICE.methods_by_name['CreateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002\036\"\034/testsets/{testset_id}/tests'
  _TESTINGSERVICE.methods_by_name['UpdateTest']._options = None
  _TESTINGSERVICE.methods_by_name['UpdateTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002(\032&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['DeleteTest']._options = None
  _TESTINGSERVICE.methods_by_name['DeleteTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\014\365\342\n\000\000 A\370\342\n\310\001\202\323\344\223\002(*&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['DescribeTest']._options = None
  _TESTINGSERVICE.methods_by_name['DescribeTest']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002(\022&/testsets/{testset_id}/tests/{test_id}'
  _TESTINGSERVICE.methods_by_name['ListTests']._options = None
  _TESTINGSERVICE.methods_by_name['ListTests']._serialized_options = b'\202\343\n\027\212\343\n\023atlas:problem:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\036\022\034/testsets/{testset_id}/tests'
  _TESTINGSERVICE.methods_by_name['ListExamples']._options = None
  _TESTINGSERVICE.methods_by_name['ListExamples']._serialized_options = b'\202\343\n\026\212\343\n\022atlas:problem:read\352\342\n\013\365\342\n\000\000\240A\370\342\nd\202\323\344\223\002\013\022\t/examples'
  _UPDATETESTINGCONFIGINPUT._serialized_start=330
  _UPDATETESTINGCONFIGINPUT._serialized_end=401
  _UPDATETESTINGCONFIGOUTPUT._serialized_start=403
  _UPDATETESTINGCONFIGOUTPUT._serialized_end=430
  _DESCRIBETESTINGCONFIGINPUT._serialized_start=432
  _DESCRIBETESTINGCONFIGINPUT._serialized_end=477
  _DESCRIBETESTINGCONFIGOUTPUT._serialized_start=479
  _DESCRIBETESTINGCONFIGOUTPUT._serialized_end=553
  _UPDATECHECKERINPUT._serialized_start=555
  _UPDATECHECKERINPUT._serialized_end=615
  _UPDATECHECKEROUTPUT._serialized_start=617
  _UPDATECHECKEROUTPUT._serialized_end=638
  _DESCRIBECHECKERINPUT._serialized_start=640
  _DESCRIBECHECKERINPUT._serialized_end=679
  _DESCRIBECHECKEROUTPUT._serialized_start=681
  _DESCRIBECHECKEROUTPUT._serialized_end=744
  _UPDATEINTERACTORINPUT._serialized_start=746
  _UPDATEINTERACTORINPUT._serialized_end=815
  _UPDATEINTERACTOROUTPUT._serialized_start=817
  _UPDATEINTERACTOROUTPUT._serialized_end=841
  _DESCRIBEINTERACTORINPUT._serialized_start=843
  _DESCRIBEINTERACTORINPUT._serialized_end=885
  _DESCRIBEINTERACTOROUTPUT._serialized_start=887
  _DESCRIBEINTERACTOROUTPUT._serialized_end=959
  _LISTTESTSETSINPUT._serialized_start=961
  _LISTTESTSETSINPUT._serialized_end=1027
  _LISTTESTSETSOUTPUT._serialized_start=1029
  _LISTTESTSETSOUTPUT._serialized_end=1102
  _DESCRIBETESTSETINPUT._serialized_start=1104
  _DESCRIBETESTSETINPUT._serialized_end=1163
  _DESCRIBETESTSETOUTPUT._serialized_start=1165
  _DESCRIBETESTSETOUTPUT._serialized_end=1228
  _CREATETESTSETINPUT._serialized_start=1230
  _CREATETESTSETINPUT._serialized_end=1290
  _CREATETESTSETOUTPUT._serialized_start=1292
  _CREATETESTSETOUTPUT._serialized_end=1325
  _UPDATETESTSETINPUT._serialized_start=1327
  _UPDATETESTSETINPUT._serialized_end=1407
  _UPDATETESTSETOUTPUT._serialized_start=1409
  _UPDATETESTSETOUTPUT._serialized_end=1430
  _DELETETESTSETINPUT._serialized_start=1432
  _DELETETESTSETINPUT._serialized_end=1472
  _DELETETESTSETOUTPUT._serialized_start=1474
  _DELETETESTSETOUTPUT._serialized_end=1495
  _LISTEXAMPLESINPUT._serialized_start=1497
  _LISTEXAMPLESINPUT._serialized_end=1533
  _LISTEXAMPLESOUTPUT._serialized_start=1535
  _LISTEXAMPLESOUTPUT._serialized_end=1593
  _LISTTESTSINPUT._serialized_start=1595
  _LISTTESTSINPUT._serialized_end=1648
  _LISTTESTSOUTPUT._serialized_start=1650
  _LISTTESTSOUTPUT._serialized_end=1717
  _DESCRIBETESTINPUT._serialized_start=1719
  _DESCRIBETESTINPUT._serialized_end=1792
  _DESCRIBETESTOUTPUT._serialized_start=1794
  _DESCRIBETESTOUTPUT._serialized_end=1848
  _CREATETESTINPUT._serialized_start=1850
  _CREATETESTINPUT._serialized_end=1921
  _CREATETESTOUTPUT._serialized_start=1923
  _CREATETESTOUTPUT._serialized_end=1958
  _UPDATETESTINPUT._serialized_start=1961
  _UPDATETESTINPUT._serialized_end=2243
  _UPDATETESTINPUT_PATCH._serialized_start=2104
  _UPDATETESTINPUT_PATCH._serialized_end=2243
  _UPDATETESTOUTPUT._serialized_start=2245
  _UPDATETESTOUTPUT._serialized_end=2263
  _DELETETESTINPUT._serialized_start=2265
  _DELETETESTINPUT._serialized_end=2319
  _DELETETESTOUTPUT._serialized_start=2321
  _DELETETESTOUTPUT._serialized_end=2339
  _TESTINGSERVICE._serialized_start=2342
  _TESTINGSERVICE._serialized_end=5070
# @@protoc_insertion_point(module_scope)



from eolymp.worker import job_pb2 as _job_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class JobTriggerEvent(_message.Message):
    __slots__ = ["job"]
    JOB_FIELD_NUMBER: _ClassVar[int]
    job: _job_pb2.Job
    def __init__(self, job: _Optional[_Union[_job_pb2.Job, _Mapping]] = ...) -> None: ...



from eolymp.ecm import content_pb2 as _content_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Penalty(_message.Message):
    __slots__ = ["cancelled_at", "created_at", "description", "expires_at", "id", "scope", "summary"]
    class Extra(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    CANCELLED_AT_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_RENDER: Penalty.Extra
    DESCRIPTION_VALUE: Penalty.Extra
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    NO_EXTRA: Penalty.Extra
    SCOPE_FIELD_NUMBER: _ClassVar[int]
    SUMMARY_FIELD_NUMBER: _ClassVar[int]
    cancelled_at: _timestamp_pb2.Timestamp
    created_at: _timestamp_pb2.Timestamp
    description: _content_pb2.Content
    expires_at: _timestamp_pb2.Timestamp
    id: str
    scope: _containers.RepeatedScalarFieldContainer[str]
    summary: str
    def __init__(self, id: _Optional[str] = ..., summary: _Optional[str] = ..., description: _Optional[_Union[_content_pb2.Content, _Mapping]] = ..., scope: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., cancelled_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/ticket_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.ecm import content_pb2 as eolymp_dot_ecm_dot_content__pb2
from eolymp.judge import ticket_pb2 as eolymp_dot_judge_dot_ticket__pb2
from eolymp.judge import ticket_reply_pb2 as eolymp_dot_judge_dot_ticket__reply__pb2
from eolymp.wellknown import direction_pb2 as eolymp_dot_wellknown_dot_direction__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!eolymp/judge/ticket_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x18\x65olymp/ecm/content.proto\x1a\x19\x65olymp/judge/ticket.proto\x1a\x1f\x65olymp/judge/ticket_reply.proto\x1a eolymp/wellknown/direction.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"_\n\x12TicketChangedEvent\x12$\n\x06\x62\x65\x66ore\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\x12#\n\x05\x61\x66ter\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"o\n\x11ReplyChangedEvent\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12#\n\x06\x62\x65\x66ore\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\x12\"\n\x05\x61\x66ter\x18\x03 \x01(\x0b\x32\x13.eolymp.judge.Reply\"s\n\x11\x43reateTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0f\n\x07subject\x18\x02 \x01(\t\x12$\n\x07message\x18\x04 \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x13\n\x0braw_message\x18\x03 \x01(\t\"\'\n\x12\x43reateTicketOutput\x12\x11\n\tticket_id\x18\x01 \x01(\t\"\xad\x01\n\x11UpdateTicketInput\x12\x34\n\x05patch\x18\x03 \x03(\x0e\x32%.eolymp.judge.UpdateTicketInput.Patch\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\")\n\x05Patch\x12\x07\n\x03\x41LL\x10\x00\x12\n\n\x06STATUS\x10\x01\x12\x0b\n\x07SUBJECT\x10\x02\"\x14\n\x12UpdateTicketOutput\"g\n\x0fReadTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x12\n\x10ReadTicketOutput\":\n\x11\x44\x65leteTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\"\x14\n\x12\x44\x65leteTicketOutput\"h\n\x13\x44\x65scribeTicketInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tticket_id\x18\x02 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"<\n\x14\x44\x65scribeTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"\xc7\x05\n\x10ListTicketsInput\x12\r\n\x05\x61\x66ter\x18\x0c \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12\x36\n\x07\x66ilters\x18( \x01(\x0b\x32%.eolymp.judge.ListTicketsInput.Filter\x12\x31\n\x04sort\x18\x32 \x01(\x0e\x32#.eolymp.judge.ListTicketsInput.Sort\x12*\n\x05order\x18\x33 \x01(\x0e\x32\x1b.eolymp.wellknown.Direction\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\x1a\x9a\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\ncontest_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\tmember_id\x18\x08 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x31\n\x07is_read\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x31\n\x07is_open\x18\x06 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12-\n\x03own\x18\x07 \x03(\x0b\x32 .eolymp.wellknown.ExpressionBool\x12\x30\n\x06status\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"&\n\x04Sort\x12\x0e\n\nCREATED_AT\x10\x00\x12\x0e\n\nUPDATED_AT\x10\x01\"a\n\x11ListTicketsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12#\n\x05items\x18\x02 \x03(\x0b\x32\x14.eolymp.judge.Ticket\x12\x18\n\x10next_page_cursor\x18\x03 \x01(\t\"\x82\x01\n\x10ReplyTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12$\n\x07message\x18\n \x01(\x0b\x32\x13.eolymp.ecm.Content\x12\x35\n\x10\x63hange_status_to\x18\x14 \x01(\x0e\x32\x1b.eolymp.judge.Ticket.Status\"%\n\x11ReplyTicketOutput\x12\x10\n\x08reply_id\x18\x01 \x01(\t\"Q\n\x10WatchTicketInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"9\n\x11WatchTicketOutput\x12$\n\x06ticket\x18\x01 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"v\n\x11WatchTicketsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\x12*\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1a.eolymp.judge.Ticket.Extra\"\xb4\x01\n\x12WatchTicketsOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchTicketsOutput.Event\x12$\n\x06ticket\x18\x02 \x01(\x0b\x32\x14.eolymp.judge.Ticket\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\"@\n\x17WatchTicketSummaryInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"J\n\x18WatchTicketSummaryOutput\x12\x14\n\x0cunread_count\x18\x03 \x01(\r\x12\x18\n\x10unresolved_count\x18\x04 \x01(\r\"n\n\x10ListRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"F\n\x11ListRepliesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\"\n\x05items\x18\x02 \x03(\x0b\x32\x13.eolymp.judge.Reply\"d\n\x12\x44\x65scribeReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"9\n\x13\x44\x65scribeReplyOutput\x12\"\n\x05reply\x18\x01 \x01(\x0b\x32\x13.eolymp.judge.Reply\"7\n\x10\x44\x65leteReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\"\x13\n\x11\x44\x65leteReplyOutput\"]\n\x10UpdateReplyInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x10\n\x08reply_id\x18\x02 \x01(\t\x12$\n\x07message\x18\x03 \x01(\x0b\x32\x13.eolymp.ecm.Content\"\x13\n\x11UpdateReplyOutput\"a\n\x11WatchRepliesInput\x12\x11\n\tticket_id\x18\x01 \x01(\t\x12\x0e\n\x06\x63ursor\x18\x02 \x01(\t\x12)\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x19.eolymp.judge.Reply.Extra\"\xb2\x01\n\x12WatchRepliesOutput\x12\x35\n\x05\x65vent\x18\x01 \x01(\x0e\x32&.eolymp.judge.WatchRepliesOutput.Event\x12\"\n\x05reply\x18\x02 \x01(\x0b\x32\x13.eolymp.judge.Reply\"A\n\x05\x45vent\x12\x11\n\rUNKNOWN_EVENT\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0b\n\x07UPDATED\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x32\xc9\x11\n\rTicketService\x12\x93\x01\n\x0c\x43reateTicket\x12\x1f.eolymp.judge.CreateTicketInput\x1a .eolymp.judge.CreateTicketOutput\"@\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\n\"\x08/tickets\x12\x99\x01\n\x0cUpdateTicket\x12\x1f.eolymp.judge.UpdateTicketInput\x1a .eolymp.judge.UpdateTicketOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x16\"\x14/tickets/{ticket_id}\x12\x97\x01\n\nReadTicket\x12\x1d.eolymp.judge.ReadTicketInput\x1a\x1e.eolymp.judge.ReadTicketOutput\"J\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1b\"\x19/tickets/{ticket_id}/read\x12\x99\x01\n\x0c\x44\x65leteTicket\x12\x1f.eolymp.judge.DeleteTicketInput\x1a .eolymp.judge.DeleteTicketOutput\"F\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16*\x14/tickets/{ticket_id}\x12\x9e\x01\n\x0e\x44\x65scribeTicket\x12!.eolymp.judge.DescribeTicketInput\x1a\".eolymp.judge.DescribeTicketOutput\"E\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x16\x12\x14/tickets/{ticket_id}\x12\x89\x01\n\x0bListTickets\x12\x1e.eolymp.judge.ListTicketsInput\x1a\x1f.eolymp.judge.ListTicketsOutput\"9\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\n\x12\x08/tickets\x12\xa4\x01\n\x0bReplyTicket\x12\x1e.eolymp.judge.ReplyTicketInput\x1a\x1f.eolymp.judge.ReplyTicketOutput\"T\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1e\"\x1c/tickets/{ticket_id}/replies\x12l\n\x0bWatchTicket\x12\x1e.eolymp.judge.WatchTicketInput\x1a\x1f.eolymp.judge.WatchTicketOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12o\n\x0cWatchTickets\x12\x1f.eolymp.judge.WatchTicketsInput\x1a .eolymp.judge.WatchTicketsOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x81\x01\n\x12WatchTicketSummary\x12%.eolymp.judge.WatchTicketSummaryInput\x1a&.eolymp.judge.WatchTicketSummaryOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\x9d\x01\n\x0bListReplies\x12\x1e.eolymp.judge.ListRepliesInput\x1a\x1f.eolymp.judge.ListRepliesOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x1e\x12\x1c/tickets/{ticket_id}/replies\x12\xaf\x01\n\rDescribeReply\x12 .eolymp.judge.DescribeReplyInput\x1a!.eolymp.judge.DescribeReplyOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\x12\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0b\x44\x65leteReply\x12\x1e.eolymp.judge.DeleteReplyInput\x1a\x1f.eolymp.judge.DeleteReplyOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)*\'/tickets/{ticket_id}/replies/{reply_id}\x12\xa9\x01\n\x0bUpdateReply\x12\x1e.eolymp.judge.UpdateReplyInput\x1a\x1f.eolymp.judge.UpdateReplyOutput\"Y\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02)\"\'/tickets/{ticket_id}/replies/{reply_id}\x12o\n\x0cWatchReplies\x12\x1f.eolymp.judge.WatchRepliesInput\x1a .eolymp.judge.WatchRepliesOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x42-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.ticket_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _TICKETSERVICE.methods_by_name['CreateTicket']._options = None
  _TICKETSERVICE.methods_by_name['CreateTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\n\"\010/tickets'
  _TICKETSERVICE.methods_by_name['UpdateTicket']._options = None
  _TICKETSERVICE.methods_by_name['UpdateTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\026\"\024/tickets/{ticket_id}'
  _TICKETSERVICE.methods_by_name['ReadTicket']._options = None
  _TICKETSERVICE.methods_by_name['ReadTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\033\"\031/tickets/{ticket_id}/read'
  _TICKETSERVICE.methods_by_name['DeleteTicket']._options = None
  _TICKETSERVICE.methods_by_name['DeleteTicket']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026*\024/tickets/{ticket_id}'
  _TICKETSERVICE.methods_by_name['DescribeTicket']._options = None
  _TICKETSERVICE.methods_by_name['DescribeTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\026\022\024/tickets/{ticket_id}'
  _TICKETSERVICE.methods_by_name['ListTickets']._options = None
  _TICKETSERVICE.methods_by_name['ListTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\n\022\010/tickets'
  _TICKETSERVICE.methods_by_name['ReplyTicket']._options = None
  _TICKETSERVICE.methods_by_name['ReplyTicket']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002\036\"\034/tickets/{ticket_id}/replies'
  _TICKETSERVICE.methods_by_name['WatchTicket']._options = None
  _TICKETSERVICE.methods_by_name['WatchTicket']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _TICKETSERVICE.methods_by_name['WatchTickets']._options = None
  _TICKETSERVICE.methods_by_name['WatchTickets']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _TICKETSERVICE.methods_by_name['WatchTicketSummary']._options = None
  _TICKETSERVICE.methods_by_name['WatchTicketSummary']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _TICKETSERVICE.methods_by_name['ListReplies']._options = None
  _TICKETSERVICE.methods_by_name['ListReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\036\022\034/tickets/{ticket_id}/replies'
  _TICKETSERVICE.methods_by_name['DescribeReply']._options = None
  _TICKETSERVICE.methods_by_name['DescribeReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002)\022\'/tickets/{ticket_id}/replies/{reply_id}'
  _TICKETSERVICE.methods_by_name['DeleteReply']._options = None
  _TICKETSERVICE.methods_by_name['DeleteReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002)*\'/tickets/{ticket_id}/replies/{reply_id}'
  _TICKETSERVICE.methods_by_name['UpdateReply']._options = None
  _TICKETSERVICE.methods_by_name['UpdateReply']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\n\327#>\370\342\n\005\202\323\344\223\002)\"\'/tickets/{ticket_id}/replies/{reply_id}'
  _TICKETSERVICE.methods_by_name['WatchReplies']._options = None
  _TICKETSERVICE.methods_by_name['WatchReplies']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _TICKETCHANGEDEVENT._serialized_start=338
  _TICKETCHANGEDEVENT._serialized_end=433
  _REPLYCHANGEDEVENT._serialized_start=435
  _REPLYCHANGEDEVENT._serialized_end=546
  _CREATETICKETINPUT._serialized_start=548
  _CREATETICKETINPUT._serialized_end=663
  _CREATETICKETOUTPUT._serialized_start=665
  _CREATETICKETOUTPUT._serialized_end=704
  _UPDATETICKETINPUT._serialized_start=707
  _UPDATETICKETINPUT._serialized_end=880
  _UPDATETICKETINPUT_PATCH._serialized_start=839
  _UPDATETICKETINPUT_PATCH._serialized_end=880
  _UPDATETICKETOUTPUT._serialized_start=882
  _UPDATETICKETOUTPUT._serialized_end=902
  _READTICKETINPUT._serialized_start=904
  _READTICKETINPUT._serialized_end=1007
  _READTICKETOUTPUT._serialized_start=1009
  _READTICKETOUTPUT._serialized_end=1027
  _DELETETICKETINPUT._serialized_start=1029
  _DELETETICKETINPUT._serialized_end=1087
  _DELETETICKETOUTPUT._serialized_start=1089
  _DELETETICKETOUTPUT._serialized_end=1109
  _DESCRIBETICKETINPUT._serialized_start=1111
  _DESCRIBETICKETINPUT._serialized_end=1215
  _DESCRIBETICKETOUTPUT._serialized_start=1217
  _DESCRIBETICKETOUTPUT._serialized_end=1277
  _LISTTICKETSINPUT._serialized_start=1280
  _LISTTICKETSINPUT._serialized_end=1991
  _LISTTICKETSINPUT_FILTER._serialized_start=1541
  _LISTTICKETSINPUT_FILTER._serialized_end=1951
  _LISTTICKETSINPUT_SORT._serialized_start=1953
  _LISTTICKETSINPUT_SORT._serialized_end=1991
  _LISTTICKETSOUTPUT._serialized_start=1993
  _LISTTICKETSOUTPUT._serialized_end=2090
  _REPLYTICKETINPUT._serialized_start=2093
  _REPLYTICKETINPUT._serialized_end=2223
  _REPLYTICKETOUTPUT._serialized_start=2225
  _REPLYTICKETOUTPUT._serialized_end=2262
  _WATCHTICKETINPUT._serialized_start=2264
  _WATCHTICKETINPUT._serialized_end=2345
  _WATCHTICKETOUTPUT._serialized_start=2347
  _WATCHTICKETOUTPUT._serialized_end=2404
  _WATCHTICKETSINPUT._serialized_start=2406
  _WATCHTICKETSINPUT._serialized_end=2524
  _WATCHTICKETSOUTPUT._serialized_start=2527
  _WATCHTICKETSOUTPUT._serialized_end=2707
  _WATCHTICKETSOUTPUT_EVENT._serialized_start=2642
  _WATCHTICKETSOUTPUT_EVENT._serialized_end=2707
  _WATCHTICKETSUMMARYINPUT._serialized_start=2709
  _WATCHTICKETSUMMARYINPUT._serialized_end=2773
  _WATCHTICKETSUMMARYOUTPUT._serialized_start=2775
  _WATCHTICKETSUMMARYOUTPUT._serialized_end=2849
  _LISTREPLIESINPUT._serialized_start=2851
  _LISTREPLIESINPUT._serialized_end=2961
  _LISTREPLIESOUTPUT._serialized_start=2963
  _LISTREPLIESOUTPUT._serialized_end=3033
  _DESCRIBEREPLYINPUT._serialized_start=3035
  _DESCRIBEREPLYINPUT._serialized_end=3135
  _DESCRIBEREPLYOUTPUT._serialized_start=3137
  _DESCRIBEREPLYOUTPUT._serialized_end=3194
  _DELETEREPLYINPUT._serialized_start=3196
  _DELETEREPLYINPUT._serialized_end=3251
  _DELETEREPLYOUTPUT._serialized_start=3253
  _DELETEREPLYOUTPUT._serialized_end=3272
  _UPDATEREPLYINPUT._serialized_start=3274
  _UPDATEREPLYINPUT._serialized_end=3367
  _UPDATEREPLYOUTPUT._serialized_start=3369
  _UPDATEREPLYOUTPUT._serialized_end=3388
  _WATCHREPLIESINPUT._serialized_start=3390
  _WATCHREPLIESINPUT._serialized_end=3487
  _WATCHREPLIESOUTPUT._serialized_start=3490
  _WATCHREPLIESOUTPUT._serialized_end=3668
  _WATCHREPLIESOUTPUT_EVENT._serialized_start=2642
  _WATCHREPLIESOUTPUT_EVENT._serialized_end=2707
  _TICKETSERVICE._serialized_start=3671
  _TICKETSERVICE._serialized_end=5920
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/judge/submission_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.judge import submission_pb2 as eolymp_dot_judge_dot_submission__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%eolymp/judge/submission_service.proto\x12\x0c\x65olymp.judge\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a\x1d\x65olymp/judge/submission.proto\x1a!eolymp/wellknown/expression.proto\"]\n\x15\x43reateSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\x12\x0c\n\x04lang\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\"/\n\x16\x43reateSubmissionOutput\x12\x15\n\rsubmission_id\x18\x01 \x01(\t\"\x94\x05\n\x14ListSubmissionsInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12:\n\x07\x66ilters\x18( \x01(\x0b\x32).eolymp.judge.ListSubmissionsInput.Filter\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\x1a\xdd\x03\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x36\n\x0eparticipant_id\x18\x02 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x32\n\nproblem_id\x18\x03 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\x12\x30\n\x06status\x18\x04 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12.\n\x04lang\x18\x05 \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\x12\x30\n\x05score\x18\x06 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12\x35\n\npercentage\x18\x07 \x03(\x0b\x32!.eolymp.wellknown.ExpressionFloat\x12;\n\x0csubmitted_at\x18\x08 \x03(\x0b\x32%.eolymp.wellknown.ExpressionTimestamp\x12\x33\n\tsignature\x18\t \x03(\x0b\x32 .eolymp.wellknown.ExpressionEnum\"O\n\x15ListSubmissionsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12\'\n\x05items\x18\x02 \x03(\x0b\x32\x18.eolymp.judge.Submission\"t\n\x17\x44\x65scribeSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\"H\n\x18\x44\x65scribeSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"q\n\x14WatchSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\x12.\n\x05\x65xtra\x18\xe3\x08 \x03(\x0e\x32\x1e.eolymp.judge.Submission.Extra\"E\n\x15WatchSubmissionOutput\x12,\n\nsubmission\x18\x01 \x01(\x0b\x32\x18.eolymp.judge.Submission\"B\n\x15RetestSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16RetestSubmissionOutput\"B\n\x15\x44\x65leteSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteSubmissionOutput\"C\n\x16RestoreSubmissionInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x15\n\rsubmission_id\x18\x02 \x01(\t\"\x19\n\x17RestoreSubmissionOutput\"<\n\x12RetestProblemInput\x12\x12\n\ncontest_id\x18\x01 \x01(\t\x12\x12\n\nproblem_id\x18\x02 \x01(\t\"\x15\n\x13RetestProblemOutput2\xe4\n\n\x11SubmissionService\x12\xb9\x01\n\x10\x43reateSubmission\x12#.eolymp.judge.CreateSubmissionInput\x1a$.eolymp.judge.CreateSubmissionOutput\"Z\x82\xe3\n\x1d\x8a\xe3\n\x19judge:contest:participate\xea\xe2\n\x0b\xf5\xe2\n\n\xd7#>\xf8\xe2\n\n\x82\xd3\xe4\x93\x02$\"\"/problems/{problem_id}/submissions\x12\x99\x01\n\x0fListSubmissions\x12\".eolymp.judge.ListSubmissionsInput\x1a#.eolymp.judge.ListSubmissionsOutput\"=\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x0e\x12\x0c/submissions\x12\xb2\x01\n\x12\x44\x65scribeSubmission\x12%.eolymp.judge.DescribeSubmissionInput\x1a&.eolymp.judge.DescribeSubmissionOutput\"M\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02\x1e\x12\x1c/submissions/{submission_id}\x12x\n\x0fWatchSubmission\x12\".eolymp.judge.WatchSubmissionInput\x1a#.eolymp.judge.WatchSubmissionOutput\"\x1a\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read0\x01\x12\xb4\x01\n\x10RetestSubmission\x12#.eolymp.judge.RetestSubmissionInput\x1a$.eolymp.judge.RetestSubmissionOutput\"U\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02%\"#/submissions/{submission_id}/retest\x12\xad\x01\n\x10\x44\x65leteSubmission\x12#.eolymp.judge.DeleteSubmissionInput\x1a$.eolymp.judge.DeleteSubmissionOutput\"N\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02\x1e*\x1c/submissions/{submission_id}\x12\xb8\x01\n\x11RestoreSubmission\x12$.eolymp.judge.RestoreSubmissionInput\x1a%.eolymp.judge.RestoreSubmissionOutput\"V\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\n2\x82\xd3\xe4\x93\x02&\"$/submissions/{submission_id}/restore\x12\xa5\x01\n\rRetestProblem\x12 .eolymp.judge.RetestProblemInput\x1a!.eolymp.judge.RetestProblemOutput\"O\x82\xe3\n\x17\x8a\xe3\n\x13judge:contest:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1f\x12\x1d/problems/{problem_id}/retestB-Z+github.com/eolymp/go-sdk/eolymp/judge;judgeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'eolymp.judge.submission_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/eolymp/go-sdk/eolymp/judge;judge'
  _SUBMISSIONSERVICE.methods_by_name['CreateSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['CreateSubmission']._serialized_options = b'\202\343\n\035\212\343\n\031judge:contest:participate\352\342\n\013\365\342\n\n\327#>\370\342\n\n\202\323\344\223\002$\"\"/problems/{problem_id}/submissions'
  _SUBMISSIONSERVICE.methods_by_name['ListSubmissions']._options = None
  _SUBMISSIONSERVICE.methods_by_name['ListSubmissions']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\016\022\014/submissions'
  _SUBMISSIONSERVICE.methods_by_name['DescribeSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['DescribeSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002\036\022\034/submissions/{submission_id}'
  _SUBMISSIONSERVICE.methods_by_name['WatchSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['WatchSubmission']._serialized_options = b'\202\343\n\026\212\343\n\022judge:contest:read'
  _SUBMISSIONSERVICE.methods_by_name['RetestSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['RetestSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002%\"#/submissions/{submission_id}/retest'
  _SUBMISSIONSERVICE.methods_by_name['DeleteSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['DeleteSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002\036*\034/submissions/{submission_id}'
  _SUBMISSIONSERVICE.methods_by_name['RestoreSubmission']._options = None
  _SUBMISSIONSERVICE.methods_by_name['RestoreSubmission']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000 A\370\342\n2\202\323\344\223\002&\"$/submissions/{submission_id}/restore'
  _SUBMISSIONSERVICE.methods_by_name['RetestProblem']._options = None
  _SUBMISSIONSERVICE.methods_by_name['RetestProblem']._serialized_options = b'\202\343\n\027\212\343\n\023judge:contest:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\037\022\035/problems/{problem_id}/retest'
  _CREATESUBMISSIONINPUT._serialized_start=220
  _CREATESUBMISSIONINPUT._serialized_end=313
  _CREATESUBMISSIONOUTPUT._serialized_start=315
  _CREATESUBMISSIONOUTPUT._serialized_end=362
  _LISTSUBMISSIONSINPUT._serialized_start=365
  _LISTSUBMISSIONSINPUT._serialized_end=1025
  _LISTSUBMISSIONSINPUT_FILTER._serialized_start=548
  _LISTSUBMISSIONSINPUT_FILTER._serialized_end=1025
  _LISTSUBMISSIONSOUTPUT._serialized_start=1027
  _LISTSUBMISSIONSOUTPUT._serialized_end=1106
  _DESCRIBESUBMISSIONINPUT._serialized_start=1108
  _DESCRIBESUBMISSIONINPUT._serialized_end=1224
  _DESCRIBESUBMISSIONOUTPUT._serialized_start=1226
  _DESCRIBESUBMISSIONOUTPUT._serialized_end=1298
  _WATCHSUBMISSIONINPUT._serialized_start=1300
  _WATCHSUBMISSIONINPUT._serialized_end=1413
  _WATCHSUBMISSIONOUTPUT._serialized_start=1415
  _WATCHSUBMISSIONOUTPUT._serialized_end=1484
  _RETESTSUBMISSIONINPUT._serialized_start=1486
  _RETESTSUBMISSIONINPUT._serialized_end=1552
  _RETESTSUBMISSIONOUTPUT._serialized_start=1554
  _RETESTSUBMISSIONOUTPUT._serialized_end=1578
  _DELETESUBMISSIONINPUT._serialized_start=1580
  _DELETESUBMISSIONINPUT._serialized_end=1646
  _DELETESUBMISSIONOUTPUT._serialized_start=1648
  _DELETESUBMISSIONOUTPUT._serialized_end=1672
  _RESTORESUBMISSIONINPUT._serialized_start=1674
  _RESTORESUBMISSIONINPUT._serialized_end=1741
  _RESTORESUBMISSIONOUTPUT._serialized_start=1743
  _RESTORESUBMISSIONOUTPUT._serialized_end=1768
  _RETESTPROBLEMINPUT._serialized_start=1770
  _RETESTPROBLEMINPUT._serialized_end=1830
  _RETESTPROBLEMOUTPUT._serialized_start=1832
  _RETESTPROBLEMOUTPUT._serialized_end=1853
  _SUBMISSIONSERVICE._serialized_start=1856
  _SUBMISSIONSERVICE._serialized_end=3236
# @@protoc_insertion_point(module_scope)



from eolymp.annotations import http_pb2 as _http_pb2
from eolymp.annotations import ratelimit_pb2 as _ratelimit_pb2
from eolymp.annotations import scope_pb2 as _scope_pb2
from eolymp.community import group_pb2 as _group_pb2
from eolymp.wellknown import expression_pb2 as _expression_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CreateGroupInput(_message.Message):
    __slots__ = ["group"]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class CreateGroupOutput(_message.Message):
    __slots__ = ["group_id"]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class DeleteGroupInput(_message.Message):
    __slots__ = ["group_id"]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class DeleteGroupOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class DescribeGroupInput(_message.Message):
    __slots__ = ["group_id"]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    group_id: str
    def __init__(self, group_id: _Optional[str] = ...) -> None: ...

class DescribeGroupOutput(_message.Message):
    __slots__ = ["group"]
    GROUP_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    def __init__(self, group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class ListGroupsInput(_message.Message):
    __slots__ = ["filters", "offset", "size"]
    class Filter(_message.Message):
        __slots__ = ["id", "name", "query"]
        ID_FIELD_NUMBER: _ClassVar[int]
        NAME_FIELD_NUMBER: _ClassVar[int]
        QUERY_FIELD_NUMBER: _ClassVar[int]
        id: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionID]
        name: _containers.RepeatedCompositeFieldContainer[_expression_pb2.ExpressionString]
        query: str
        def __init__(self, query: _Optional[str] = ..., id: _Optional[_Iterable[_Union[_expression_pb2.ExpressionID, _Mapping]]] = ..., name: _Optional[_Iterable[_Union[_expression_pb2.ExpressionString, _Mapping]]] = ...) -> None: ...
    FILTERS_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    filters: ListGroupsInput.Filter
    offset: int
    size: int
    def __init__(self, offset: _Optional[int] = ..., size: _Optional[int] = ..., filters: _Optional[_Union[ListGroupsInput.Filter, _Mapping]] = ...) -> None: ...

class ListGroupsOutput(_message.Message):
    __slots__ = ["items", "total"]
    ITEMS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    items: _containers.RepeatedCompositeFieldContainer[_group_pb2.Group]
    total: int
    def __init__(self, total: _Optional[int] = ..., items: _Optional[_Iterable[_Union[_group_pb2.Group, _Mapping]]] = ...) -> None: ...

class UpdateGroupInput(_message.Message):
    __slots__ = ["group", "group_id", "patch"]
    class Patch(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
    ALL: UpdateGroupInput.Patch
    DESCRIPTION: UpdateGroupInput.Patch
    GROUP_FIELD_NUMBER: _ClassVar[int]
    GROUP_ID_FIELD_NUMBER: _ClassVar[int]
    NAME: UpdateGroupInput.Patch
    PATCH_FIELD_NUMBER: _ClassVar[int]
    group: _group_pb2.Group
    group_id: str
    patch: _containers.RepeatedScalarFieldContainer[UpdateGroupInput.Patch]
    def __init__(self, patch: _Optional[_Iterable[_Union[UpdateGroupInput.Patch, str]]] = ..., group_id: _Optional[str] = ..., group: _Optional[_Union[_group_pb2.Group, _Mapping]] = ...) -> None: ...

class UpdateGroupOutput(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...



from eolymp.executor import stats_pb2 as _stats_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GenerationReport(_message.Message):
    __slots__ = ["agent", "error", "origin", "reference", "runs", "task_id"]
    class Run(_message.Message):
        __slots__ = ["answer_generator_stats", "answer_url", "input_generator_stats", "input_url", "reference", "status"]
        class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
            __slots__ = []
        ANSWER_GENERATOR_STATS_FIELD_NUMBER: _ClassVar[int]
        ANSWER_URL_FIELD_NUMBER: _ClassVar[int]
        COMPLETE: GenerationReport.Run.Status
        FAILED: GenerationReport.Run.Status
        INPUT_GENERATOR_STATS_FIELD_NUMBER: _ClassVar[int]
        INPUT_URL_FIELD_NUMBER: _ClassVar[int]
        NONE: GenerationReport.Run.Status
        PENDING: GenerationReport.Run.Status
        REFERENCE_FIELD_NUMBER: _ClassVar[int]
        STATUS_FIELD_NUMBER: _ClassVar[int]
        answer_generator_stats: _stats_pb2.Stats
        answer_url: str
        input_generator_stats: _stats_pb2.Stats
        input_url: str
        reference: str
        status: GenerationReport.Run.Status
        def __init__(self, reference: _Optional[str] = ..., status: _Optional[_Union[GenerationReport.Run.Status, str]] = ..., input_url: _Optional[str] = ..., answer_url: _Optional[str] = ..., input_generator_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ..., answer_generator_stats: _Optional[_Union[_stats_pb2.Stats, _Mapping]] = ...) -> None: ...
    AGENT_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    ORIGIN_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_FIELD_NUMBER: _ClassVar[int]
    RUNS_FIELD_NUMBER: _ClassVar[int]
    TASK_ID_FIELD_NUMBER: _ClassVar[int]
    agent: str
    error: str
    origin: str
    reference: str
    runs: _containers.RepeatedCompositeFieldContainer[GenerationReport.Run]
    task_id: str
    def __init__(self, task_id: _Optional[str] = ..., reference: _Optional[str] = ..., origin: _Optional[str] = ..., agent: _Optional[str] = ..., error: _Optional[str] = ..., runs: _Optional[_Iterable[_Union[GenerationReport.Run, _Mapping]]] = ...) -> None: ...



from .language_pb2 import *
from .configuration_service_http import *
from .runtime_service_pb2 import *
from .configuration_service_pb2 import *
from .runtime_service_http import *
from .runtime_pb2 import *
